@@ -5,21 +5,21 @@ from attrs import define, field
 from resoto_plugin_aws.resource.base import AwsResource, GraphBuilder, AwsApiSpec
 from resoto_plugin_aws.resource.ec2 import AwsEc2Vpc, AwsEc2Subnet, AwsEc2Instance, AwsEc2SecurityGroup
 from resoto_plugin_aws.utils import ToDict
-from resotolib.baseresources import BaseLoadBalancer, EdgeType, BaseAccount, ModelReference  # noqa: F401
+from resotolib.baseresources import BaseLoadBalancer, EdgeType, ModelReference
 from resotolib.json import from_json
 from resotolib.json_bender import Bender, S, Bend, bend, ForallBend, K
 from resotolib.types import Json
 from resoto_plugin_aws.aws_client import AwsClient
 
 
-# todo: annotate with no serialization annotation
+# noinspection PyUnresolvedReferences
 class ElbV2Taggable:
     def update_resource_tag(self, client: AwsClient, key: str, value: str) -> bool:
         if isinstance(self, AwsResource):
             if spec := self.api_spec:
                 client.call(
-                    service=spec.service,
-                    action="add_tags",
+                    aws_service=spec.service,
+                    action="add-tags",
                     result_name=None,
                     ResourceArns=[self.arn],
                     Tags=[{"Key": key, "Value": value}],
@@ -32,8 +32,8 @@ class ElbV2Taggable:
         if isinstance(self, AwsResource):
             if spec := self.api_spec:
                 client.call(
-                    service=spec.service,
-                    action="remove_tags",
+                    aws_service=spec.service,
+                    action="remove-tags",
                     result_name=None,
                     ResourceArns=[self.arn],
                     TagKeys=[key],
@@ -42,6 +42,13 @@ class ElbV2Taggable:
             return False
         return False
 
+    @classmethod
+    def called_mutator_apis(cls) -> List[AwsApiSpec]:
+        return [
+            AwsApiSpec("elb", "add-tags", override_iam_permission="elasticloadbalancing:AddTags"),
+            AwsApiSpec("elb", "remove-tags", override_iam_permission="elasticloadbalancing:RemoveTags"),
+        ]
+
 
 @define(eq=False, slots=False)
 class AwsAlbLoadBalancerState:
@@ -254,7 +261,12 @@ class AwsAlbListener:
 @define(eq=False, slots=False)
 class AwsAlb(ElbV2Taggable, AwsResource, BaseLoadBalancer):
     kind: ClassVar[str] = "aws_alb"
-    api_spec: ClassVar[AwsApiSpec] = AwsApiSpec("elbv2", "describe-load-balancers", "LoadBalancers")
+    api_spec: ClassVar[AwsApiSpec] = AwsApiSpec(
+        "elbv2",
+        "describe-load-balancers",
+        "LoadBalancers",
+        override_iam_permission="elasticloadbalancing:DescribeLoadBalancers",
+    )
     reference_kinds: ClassVar[ModelReference] = {
         "predecessors": {
             "default": ["aws_vpc", "aws_ec2_subnet", "aws_ec2_security_group"],
@@ -289,6 +301,14 @@ class AwsAlb(ElbV2Taggable, AwsResource, BaseLoadBalancer):
     alb_type: Optional[str] = field(default=None)
     alb_listener: List[AwsAlbListener] = field(factory=list)
 
+    @classmethod
+    def called_collect_apis(cls) -> List[AwsApiSpec]:
+        return [
+            cls.api_spec,
+            AwsApiSpec("elbv2", "describe-listeners", override_iam_permission="elasticloadbalancing:DescribeListeners"),
+            AwsApiSpec("elbv2", "describe-tags", override_iam_permission="elasticloadbalancing:DescribeTags"),
+        ]
+
     @classmethod
     def collect(cls: Type[AwsResource], json: List[Json], builder: GraphBuilder) -> None:
         for js in json:
@@ -311,10 +331,18 @@ class AwsAlb(ElbV2Taggable, AwsResource, BaseLoadBalancer):
 
     def delete_resource(self, client: AwsClient) -> bool:
         client.call(
-            service=self.api_spec.service, action="delete_load_balancer", result_name=None, LoadBalancerArn=self.arn
+            aws_service=self.api_spec.service, action="delete-load-balancer", result_name=None, LoadBalancerArn=self.arn
         )
         return True
 
+    @classmethod
+    def called_mutator_apis(cls) -> List[AwsApiSpec]:
+        return super().called_mutator_apis() + [
+            AwsApiSpec(
+                "elbv2", "delete-load-balancer", override_iam_permission="elasticloadbalancing:DeleteLoadBalancer"
+            ),
+        ]
+
 
 @define(eq=False, slots=False)
 class AwsAlbMatcher:
@@ -349,7 +377,12 @@ class AwsAlbTargetHealth:
 @define(eq=False, slots=False)
 class AwsAlbTargetHealthDescription:
     kind: ClassVar[str] = "aws_alb_target_health_description"
-    api_spec: ClassVar[AwsApiSpec] = AwsApiSpec("elbv2", "describe-target-health", "TargetHealthDescriptions")
+    api_spec: ClassVar[AwsApiSpec] = AwsApiSpec(
+        "elbv2",
+        "describe-target-health",
+        "TargetHealthDescriptions",
+        override_iam_permission="elasticloadbalancing:DescribeTargetHealth",
+    )
     mapping: ClassVar[Dict[str, Bender]] = {
         "target": S("Target") >> Bend(AwsAlbTargetDescription.mapping),
         "health_check_port": S("HealthCheckPort"),
@@ -363,7 +396,12 @@ class AwsAlbTargetHealthDescription:
 @define(eq=False, slots=False)
 class AwsAlbTargetGroup(ElbV2Taggable, AwsResource):
     kind: ClassVar[str] = "aws_alb_target_group"
-    api_spec: ClassVar[AwsApiSpec] = AwsApiSpec("elbv2", "describe-target-groups", "TargetGroups")
+    api_spec: ClassVar[AwsApiSpec] = AwsApiSpec(
+        "elbv2",
+        "describe-target-groups",
+        "TargetGroups",
+        override_iam_permission="elasticloadbalancing:DescribeTargetGroups",
+    )
     reference_kinds: ClassVar[ModelReference] = {
         "predecessors": {"default": ["aws_vpc", "aws_alb"], "delete": ["aws_ec2_instance", "aws_vpc"]},
         "successors": {"delete": ["aws_alb"], "default": ["aws_ec2_instance"]},
@@ -404,6 +442,16 @@ class AwsAlbTargetGroup(ElbV2Taggable, AwsResource):
     alb_ip_address_type: Optional[str] = field(default=None)
     alb_target_health: List[AwsAlbTargetHealthDescription] = field(factory=list)
 
+    @classmethod
+    def called_collect_apis(cls) -> List[AwsApiSpec]:
+        return [
+            cls.api_spec,
+            AwsApiSpec(
+                "elbv2", "describe-target-health", override_iam_permission="elasticloadbalancing:DescribeTargetHealth"
+            ),
+            AwsApiSpec("elbv2", "describe-tags", override_iam_permission="elasticloadbalancing:DescribeTags"),
+        ]
+
     @classmethod
     def collect(cls: Type[AwsResource], json: List[Json], builder: GraphBuilder) -> None:
         for js in json:
@@ -431,9 +479,17 @@ class AwsAlbTargetGroup(ElbV2Taggable, AwsResource):
 
     def delete_resource(self, client: AwsClient) -> bool:
         client.call(
-            service=self.api_spec.service, action="delete_target_group", result_name=None, TargetGroupArn=self.arn
+            aws_service=self.api_spec.service, action="delete-target-group", result_name=None, TargetGroupArn=self.arn
         )
         return True
 
+    @classmethod
+    def called_mutator_apis(cls) -> List[AwsApiSpec]:
+        return super().called_mutator_apis() + [
+            AwsApiSpec(
+                "elbv2", "delete-target-group", override_iam_permission="elasticloadbalancing:DeleteTargetGroup"
+            ),
+        ]
+
 
 resources: List[Type[AwsResource]] = [AwsAlb, AwsAlbTargetGroup]
