@@ -7,11 +7,10 @@ from resoto_plugin_aws.resource.base import AwsResource, GraphBuilder, AwsApiSpe
 from resoto_plugin_aws.resource.ec2 import AwsEc2IamInstanceProfile
 from resoto_plugin_aws.utils import ToDict
 
-from resotolib.baseresources import (  # noqa: F401
+from resotolib.baseresources import (
     BaseCertificate,
     BasePolicy,
     BaseGroup,
-    BaseAccount,
     BaseAccessKey,
     BaseUser,
     BaseInstanceProfile,
@@ -19,7 +18,7 @@ from resotolib.baseresources import (  # noqa: F401
     ModelReference,
 )
 from resotolib.json import from_json
-from resotolib.json_bender import Bender, S, Bend, AsDate, Sort, bend, ForallBend
+from resotolib.json_bender import Bender, S, Bend, AsDate, Sort, bend, ForallBend, F
 from resotolib.types import Json
 from resotolib.graph import Graph
 from resoto_plugin_aws.aws_client import AwsClient
@@ -28,7 +27,7 @@ from resoto_plugin_aws.aws_client import AwsClient
 def iam_update_tag(resource: AwsResource, client: AwsClient, action: str, key: str, value: str, **kwargs: Any) -> bool:
     if spec := resource.api_spec:
         client.call(
-            service=spec.service,
+            aws_service=spec.service,
             action=action,
             result_name=None,
             Tags=[{"Key": key, "Value": value}],
@@ -41,7 +40,7 @@ def iam_update_tag(resource: AwsResource, client: AwsClient, action: str, key: s
 def iam_delete_tag(resource: AwsResource, client: AwsClient, action: str, key: str, **kwargs: Any) -> bool:
     if spec := resource.api_spec:
         client.call(
-            service=spec.service,
+            aws_service=spec.service,
             action=action,
             result_name=None,
             TagKeys=[key],
@@ -56,7 +55,7 @@ class AwsIamPolicyDetail:
     kind: ClassVar[str] = "aws_iam_policy_detail"
     mapping: ClassVar[Dict[str, Bender]] = {"policy_name": S("PolicyName"), "policy_document": S("PolicyDocument")}
     policy_name: Optional[str] = field(default=None)
-    policy_document: Optional[str] = field(default=None)
+    policy_document: Optional[Json] = field(default=None)
 
 
 @define(eq=False, slots=False)
@@ -125,7 +124,7 @@ class AwsIamRole(AwsResource):
         return iam_update_tag(
             resource=self,
             client=client,
-            action="tag_role",
+            action="tag-role",
             key=key,
             value=value,
             RoleName=self.name,
@@ -135,7 +134,7 @@ class AwsIamRole(AwsResource):
         return iam_delete_tag(
             resource=self,
             client=client,
-            action="untag_role",
+            action="untag-role",
             key=key,
             RoleName=self.name,
         )
@@ -147,8 +146,8 @@ class AwsIamRole(AwsResource):
                 log_msg = f"Detaching {successor.rtdname}"
                 self.log(log_msg)
                 client.call(
-                    service="iam",
-                    action="detach_role_policy",
+                    aws_service="iam",
+                    action="detach-role-policy",
                     result_name=None,
                     PolicyArn=successor.arn,
                     RoleName=self.name,
@@ -158,8 +157,8 @@ class AwsIamRole(AwsResource):
             log_msg = f"Deleting inline policy {role_policy}"
             self.log(log_msg)
             client.call(
-                service="iam",
-                action="delete_role_policy",
+                aws_service="iam",
+                action="delete-role-policy",
                 result_name=None,
                 PolicyName=role_policy.policy_name,
                 RoleName=self.name,
@@ -168,9 +167,19 @@ class AwsIamRole(AwsResource):
         return True
 
     def delete_resource(self, client: AwsClient) -> bool:
-        client.call(service="iam", action="delete_role", result_name=None, RoleName=self.name)
+        client.call(aws_service="iam", action="delete-role", result_name=None, RoleName=self.name)
         return True
 
+    @classmethod
+    def called_mutator_apis(cls) -> List[AwsApiSpec]:
+        return [
+            AwsApiSpec("iam", "tag-role"),
+            AwsApiSpec("iam", "untag-role"),
+            AwsApiSpec("iam", "detach-role-policy"),
+            AwsApiSpec("iam", "delete-role-policy"),
+            AwsApiSpec("iam", "delete-role"),
+        ]
+
 
 @define(eq=False, slots=False)
 class AwsIamServerCertificate(AwsResource, BaseCertificate):
@@ -191,7 +200,7 @@ class AwsIamServerCertificate(AwsResource, BaseCertificate):
         return iam_update_tag(
             resource=self,
             client=client,
-            action="tag_server_certificate",
+            action="tag-server-certificate",
             key=key,
             value=value,
             ServerCertificateName=self.name,
@@ -201,20 +210,52 @@ class AwsIamServerCertificate(AwsResource, BaseCertificate):
         return iam_delete_tag(
             resource=self,
             client=client,
-            action="untag_server_certificate",
+            action="untag-server-certificate",
             key=key,
             ServerCertificateName=self.name,
         )
 
     def delete_resource(self, client: AwsClient) -> bool:
         client.call(
-            service=self.api_spec.service,
-            action="delete_server_certificate",
+            aws_service=self.api_spec.service,
+            action="delete-server-certificate",
             result_name=None,
             ServerCertificateName=self.name,
         )
         return True
 
+    @classmethod
+    def called_mutator_apis(cls) -> List[AwsApiSpec]:
+        return [
+            AwsApiSpec("iam", "tag-server-certificate"),
+            AwsApiSpec("iam", "untag-server-certificate"),
+            AwsApiSpec("iam", "delete-server-certificate"),
+        ]
+
+
+@define(eq=False, slots=False)
+class AwsIamPolicyVersion:
+    kind: ClassVar[str] = "aws_iam_policy_version"
+    mapping: ClassVar[Dict[str, Bender]] = {
+        "document": S("Document"),
+        "version_id": S("VersionId"),
+        "is_default_version": S("IsDefaultVersion"),
+        "create_date": S("CreateDate"),
+    }
+    document: Optional[Json] = field(default=None)
+    version_id: Optional[str] = field(default=None)
+    is_default_version: Optional[bool] = field(default=None)
+    create_date: Optional[datetime] = field(default=None)
+
+
+def default_policy_document(policy: Json) -> Optional[AwsIamPolicyVersion]:
+    default_version = policy.get("DefaultVersionId")
+    # select the default policy from the version list
+    for p in policy.get("PolicyVersionList", []):
+        if p.get("VersionId") == default_version:
+            return bend(AwsIamPolicyVersion.mapping, p)  # type: ignore
+    return None
+
 
 @define(eq=False, slots=False)
 class AwsIamPolicy(AwsResource, BasePolicy):
@@ -233,6 +274,7 @@ class AwsIamPolicy(AwsResource, BasePolicy):
         "policy_permissions_boundary_usage_count": S("PermissionsBoundaryUsageCount"),
         "policy_is_attachable": S("IsAttachable"),
         "policy_description": S("Description"),
+        "policy_document": F(default_policy_document),
     }
     path: Optional[str] = field(default=None)
     policy_default_version_id: Optional[str] = field(default=None)
@@ -240,12 +282,13 @@ class AwsIamPolicy(AwsResource, BasePolicy):
     policy_permissions_boundary_usage_count: Optional[int] = field(default=None)
     policy_is_attachable: Optional[bool] = field(default=None)
     policy_description: Optional[str] = field(default=None)
+    policy_document: Optional[AwsIamPolicyVersion] = field(default=None)
 
     def update_resource_tag(self, client: AwsClient, key: str, value: str) -> bool:
         return iam_update_tag(
             resource=self,
             client=client,
-            action="tag_policy",
+            action="tag-policy",
             key=key,
             value=value,
             PolicyArn=self.arn,
@@ -255,20 +298,28 @@ class AwsIamPolicy(AwsResource, BasePolicy):
         return iam_delete_tag(
             resource=self,
             client=client,
-            action="untag_policy",
+            action="untag-policy",
             key=key,
             PolicyArn=self.arn,
         )
 
     def delete_resource(self, client: AwsClient) -> bool:
         client.call(
-            service="iam",
-            action="delete_policy",
+            aws_service="iam",
+            action="delete-policy",
             result_name=None,
             PolicyArn=self.arn,
         )
         return True
 
+    @classmethod
+    def called_mutator_apis(cls) -> List[AwsApiSpec]:
+        return [
+            AwsApiSpec("iam", "tag-policy"),
+            AwsApiSpec("iam", "untag-policy"),
+            AwsApiSpec("iam", "delete-policy"),
+        ]
+
 
 @define(eq=False, slots=False)
 class AwsIamGroup(AwsResource, BaseGroup):
@@ -300,8 +351,8 @@ class AwsIamGroup(AwsResource, BaseGroup):
                 log_msg = f"Detaching {successor.rtdname}"
                 self.log(log_msg)
                 client.call(
-                    service="iam",
-                    action="detach_group_policy",
+                    aws_service="iam",
+                    action="detach-group-policy",
                     result_name=None,
                     GroupName=self.name,
                     PolicyArn=successor.arn,
@@ -311,8 +362,8 @@ class AwsIamGroup(AwsResource, BaseGroup):
             log_msg = f"Deleting inline policy {group_policy}"
             self.log(log_msg)
             client.call(
-                service="iam",
-                action="delete_group_policy",
+                aws_service="iam",
+                action="delete-group-policy",
                 result_name=None,
                 GroupName=self.name,
                 PolicyName=group_policy,
@@ -322,13 +373,21 @@ class AwsIamGroup(AwsResource, BaseGroup):
 
     def delete_resource(self, client: AwsClient) -> bool:
         client.call(
-            service="iam",
-            action="delete_group",
+            aws_service="iam",
+            action="delete-group",
             result_name=None,
             GroupName=self.name,
         )
         return True
 
+    @classmethod
+    def called_mutator_apis(cls) -> List[AwsApiSpec]:
+        return [
+            AwsApiSpec("iam", "detach-group-policy"),
+            AwsApiSpec("iam", "delete-group-policy"),
+            AwsApiSpec("iam", "delete-group"),
+        ]
+
 
 @define(eq=False, slots=False)
 class AwsIamAccessKeyLastUsed:
@@ -385,8 +444,21 @@ class AwsIamUser(AwsResource, BaseUser):
     user_policies: List[AwsIamPolicyDetail] = field(factory=list)
     user_permissions_boundary: Optional[AwsIamAttachedPermissionsBoundary] = field(default=None)
 
+    @classmethod
+    def called_collect_apis(cls) -> List[AwsApiSpec]:
+        return [
+            cls.api_spec,
+            AwsApiSpec("iam", "list-access-keys"),
+            AwsApiSpec("iam", "get-access-key-last-used"),
+            AwsApiSpec("iam", "list-users"),
+        ]
+
     @classmethod
     def collect(cls: Type[AwsResource], json_list: List[Json], builder: GraphBuilder) -> None:
+        name_password_last_used_map: Dict[str, str] = {}
+        for user in builder.client.list("iam", "list-users", "Users"):
+            if "PasswordLastUsed" in user and "UserId" in user:
+                name_password_last_used_map[user["UserId"]] = user["PasswordLastUsed"]
         for json in json_list:
             for js in json.get("GroupDetailList", []):
                 builder.add_node(AwsIamGroup.from_api(js), js)
@@ -398,6 +470,7 @@ class AwsIamUser(AwsResource, BaseUser):
                 builder.add_node(AwsIamPolicy.from_api(js), js)
 
             for js in json.get("UserDetailList", []):
+                js["PasswordLastUsed"] = name_password_last_used_map.get(js["UserId"])
                 user = AwsIamUser.from_api(js)
                 builder.add_node(user, js)
                 # add all iam access keys for this user
@@ -420,10 +493,10 @@ class AwsIamUser(AwsResource, BaseUser):
             builder.add_edge(self, reverse=True, clazz=AwsIamGroup, arn=arn)
 
     def update_resource_tag(self, client: AwsClient, key: str, value: str) -> bool:
-        return iam_update_tag(resource=self, client=client, action="tag_user", key=key, value=value, UserName=self.name)
+        return iam_update_tag(resource=self, client=client, action="tag-user", key=key, value=value, UserName=self.name)
 
     def delete_resource_tag(self, client: AwsClient, key: str) -> bool:
-        return iam_delete_tag(resource=self, client=client, action="untag_user", key=key, UserName=self.name)
+        return iam_delete_tag(resource=self, client=client, action="untag-user", key=key, UserName=self.name)
 
     def pre_delete_resource(self, client: AwsClient, graph: Graph) -> bool:
         for successor in self.successors(graph, edge_type=EdgeType.delete):
@@ -431,8 +504,8 @@ class AwsIamUser(AwsResource, BaseUser):
                 log_msg = f"Detaching {successor.rtdname}"
                 self.log(log_msg)
                 client.call(
-                    service="iam",
-                    action="detach_user_policy",
+                    aws_service="iam",
+                    action="detach-user-policy",
                     result_name=None,
                     UserName=self.name,
                     PolicyArn=successor.arn,
@@ -442,8 +515,8 @@ class AwsIamUser(AwsResource, BaseUser):
             log_msg = f"Deleting inline policy {user_policy}"
             self.log(log_msg)
             client.call(
-                service="iam",
-                action="delete_user_policy",
+                aws_service="iam",
+                action="delete-user-policy",
                 result_name=None,
                 UserName=self.name,
                 PolicyName=user_policy.policy_name,
@@ -452,9 +525,19 @@ class AwsIamUser(AwsResource, BaseUser):
         return True
 
     def delete_resource(self, client: AwsClient) -> bool:
-        client.call(service="iam", action="delete_user", result_name=None, UserName=self.name)
+        client.call(aws_service="iam", action="delete-user", result_name=None, UserName=self.name)
         return True
 
+    @classmethod
+    def called_mutator_apis(cls) -> List[AwsApiSpec]:
+        return [
+            AwsApiSpec("iam", "tag-user"),
+            AwsApiSpec("iam", "untag-user"),
+            AwsApiSpec("iam", "detach-user-policy"),
+            AwsApiSpec("iam", "delete-user-policy"),
+            AwsApiSpec("iam", "delete-user"),
+        ]
+
 
 @define(eq=False, slots=False)
 class AwsIamInstanceProfile(AwsResource, BaseInstanceProfile):
@@ -473,7 +556,7 @@ class AwsIamInstanceProfile(AwsResource, BaseInstanceProfile):
         return iam_update_tag(
             resource=self,
             client=client,
-            action="tag_instance_profile",
+            action="tag-instance-profile",
             key=key,
             value=value,
             InstanceProfileName=self.name,
@@ -481,7 +564,7 @@ class AwsIamInstanceProfile(AwsResource, BaseInstanceProfile):
 
     def delete_resource_tag(self, client: AwsClient, key: str) -> bool:
         return iam_delete_tag(
-            resource=self, client=client, action="untag_instance_profile", key=key, InstanceProfileName=self.name
+            resource=self, client=client, action="untag-instance-profile", key=key, InstanceProfileName=self.name
         )
 
     def pre_delete_resource(self, client: AwsClient, graph: Graph) -> bool:
@@ -490,8 +573,8 @@ class AwsIamInstanceProfile(AwsResource, BaseInstanceProfile):
                 log_msg = f"Detaching {predecessor.rtdname}"
                 self.log(log_msg)
                 client.call(
-                    service="iam",
-                    action="remove_role_from_instance_profile",
+                    aws_service="iam",
+                    action="remove-role-from-instance-profile",
                     result_name=None,
                     RoleName=predecessor.name,
                     InstanceProfileName=self.name,
@@ -499,9 +582,20 @@ class AwsIamInstanceProfile(AwsResource, BaseInstanceProfile):
         return True
 
     def delete_resource(self, client: AwsClient) -> bool:
-        client.call(service="iam", action="delete_instance_profile", result_name=None, InstanceProfileName=self.name)
+        client.call(
+            aws_service="iam", action="delete-instance-profile", result_name=None, InstanceProfileName=self.name
+        )
         return True
 
+    @classmethod
+    def called_mutator_apis(cls) -> List[AwsApiSpec]:
+        return [
+            AwsApiSpec("iam", "tag-instance-profile"),
+            AwsApiSpec("iam", "untag-instance-profile"),
+            AwsApiSpec("iam", "remove-role-from-instance-profile"),
+            AwsApiSpec("iam", "delete-instance-profile"),
+        ]
+
 
 resources: List[Type[AwsResource]] = [
     AwsIamServerCertificate,
